## This file generated by InlineX::C2XS (version 0.28) using Inline::C (version 0.82)
package Math::GMPf::Random;
use strict;
use warnings;

require Exporter;
*import = \&Exporter::import;
require DynaLoader;

our $VERSION = '0.53';
$VERSION = eval $VERSION;
DynaLoader::bootstrap Math::GMPf::Random $VERSION;

@Math::GMPf::Random::EXPORT = ();
@Math::GMPf::Random::EXPORT_OK = ();

sub dl_load_flags {0} # Prevent DynaLoader from complaining and croaking

sub _issue_19550 { # https://github.com/Perl/perl5/issues/19550
  my $inf = 999 ** (999 ** 999);
  my $discard = "$inf";
  my $inf_copy = $inf;
  # Using Math::GMPf::Random::_is_NOK_and_POK():
  return 1
    if(!_is_NOK_and_POK($inf) && _is_NOK_and_POK($inf_copy));
  return 0;
}

1;
